==> mdm-rpc-0.1.23-sources.jar: com/chinayanghe/msp/mdm/vo/user/UserPositionVo.java <==
package com.chinayanghe.msp.mdm.vo.user;

import java.io.Serializable;

/**
 * Created by Administrator on 2017/5/25 0025.
 */
public class UserPositionVo implements Serializable {
    private static final long serialVersionUID = 5997236440569163438L;
    //主键
    private String id;
    //岗位编码
    private String positionCode;
    //岗位名称
    private String positionName;
    //与岗位表关联的外键
    private String positionId;
    //人员编码
    private String userCode;
    //与人员表关联的外键
    private String userId;
    //是否主岗标记0：主岗，1：副岗
    private String positionFlag;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getPositionFlag() {
        return positionFlag;
    }

    public void setPositionFlag(String positionFlag) {
        this.positionFlag = positionFlag;
    }
}

==> mdm-rpc-0.1.30-sources.jar: com/chinayanghe/msp/mdm/vo/user/UserPositionVo.java <==
package com.chinayanghe.msp.mdm.vo.user;

import java.io.Serializable;

/**
 * Created by Administrator on 2017/5/25 0025.
 */
public class UserPositionVo implements Serializable {
    private static final long serialVersionUID = 5997236440569163438L;
    //主键
    private String id;
    //岗位编码
    private String positionCode;
    //岗位名称
    private String positionName;
    //与岗位表关联的外键
    private String positionId;
    //人员编码
    private String userCode;
    //与人员表关联的外键
    private String userId;
    //是否主岗标记0：主岗，1：副岗
    private String positionFlag;

    //岗位所属组织编码
    private String orgCode;

    //岗位所属组织名称
    private String orgName;

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getPositionCode() {
        return positionCode;
    }

    public void setPositionCode(String positionCode) {
        this.positionCode = positionCode;
    }

    public String getPositionName() {
        return positionName;
    }

    public void setPositionName(String positionName) {
        this.positionName = positionName;
    }

    public String getPositionId() {
        return positionId;
    }

    public void setPositionId(String positionId) {
        this.positionId = positionId;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getPositionFlag() {
        return positionFlag;
    }

    public void setPositionFlag(String positionFlag) {
        this.positionFlag = positionFlag;
    }
}
